/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ConnectorForm.java,v 1.10 2004/12/20 14:54:53 danesa Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.catalina;

import java.net.InetAddress;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

/**
 * Form bean for the connector page.
 *
 * @author Michel-Ange ANTON
 * @author Adriana Danes - update to Tomact 5.0
 */

public final class ConnectorForm extends ActionForm {

    // ----------------------------------------------------- Instance Variables

    /**
     * The administrative action represented by this form.
     */
    private String action = "edit";

    /**
     * The administrative sub-action state.
     */
    private boolean save = false;

    /**
     * The object name of the Connector this bean refers to.
     */
    private String objectName = null;

    /**
     * The name of the service this connector belongs to.
     */
    private String serviceName = null;

    /**
     * The text for the scheme.
     */
    private String scheme = null;

    /**
     * The text for the connector type.
     * Specifies if it is a CoyoteConnector or AJP13Connector etc.
     */
    private String connectorType = null;

    /**
     * The text for the node label.
     */

    /**
     * The text for the accept Count.
     */
    private String acceptCountText = "10";

    /**
     * The text for the Connection Time Out.
     */
    private String connTimeOutText = "60000";

    /**
     * The text for the debug level.
     */
    private String debugLvl = "0";

    /**
     * The text for the buffer size.
     */
    private String bufferSizeText = "2048";

    /**
     * The value of enable Lookups.
     */
    private boolean enableLookups = true;

    /**
     * The text for the IP address on which to bind.
     */
    private String address = null;

    /**
     * The text for the min Spare Threads.
     */
    private String minSpareThreadsText = null;

    /**
     * The text for the max Spare Threads.
     */
    private String maxSpareThreadsText = null;

    /**
     * The text for the max Threads.
     */
    private String maxThreadsText = null;

    /**
     * The text for the port.
     */
    private String portText = null;

    /**
     * The text for the redirect port.
     */
    private String redirectPortText = "-1";

    /**
     * The text for the proxyName.
     */
    private String proxyName = null;

    /**
     * The text for the proxy Port Number.
     */
    private String proxyPortText = "0";

    /**
     * The text for the connectorName.
     */
    private String connectorName = null;

    /**
     * Whether client authentication is supported.
     */
    private boolean clientAuthentication = false;

    /**
     * The keyStore Filename.
     */
    private String keyStoreFileName = null;

    /**
     * The keyStore Password.
     */
    private String keyStorePassword = null;

    /**
     * Set of valid values for debug level.
     */
    private List debugLvlVals = null;

    /**
     * Represent boolean (true, false) values for enableLookups etc.
     */
    private List booleanVals = null;

    /**
     * Represent supported connector types.
     */
    private List connectorTypeVals = null;

    /**
     * The text for the minProcessors.
     */
    private String minProcessorsText = "5";

    /**
     * The text for the maxProcessors.
     */
    private String maxProcessorsText = "20";

    // --------------------------------------------------------- Public Methods
    /**
     * Validate the properties that have been set from this HTTP request,
     * and return an <code>ActionErrors</code> object that encapsulates any
     * validation errors that have been found.  If no errors are found, return
     * <code>null</code> or an <code>ActionErrors</code> object with no
     * recorded error messages.
     *
     * @param mapping The mapping used to select this instance
     * @param request The servlet request we are processing
     * @return the ActionErrors
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {

        ActionErrors oErrors = new ActionErrors();

        // general
        numberCheck(oErrors, "acceptCountText", acceptCountText, true, 0, 128);
        numberCheck(oErrors, "connTimeOutText", connTimeOutText, true, -1, 60000);
        numberCheck(oErrors, "bufferSizeText", bufferSizeText, true, 1, 8192);

        // The IP address can also be null --
        // which means open the server socket on *all* IP addresses for this host
        if (address.length() > 0) {
            try {
                InetAddress.getByName(address);
            } catch (Exception e) {
                oErrors.add("address", new ActionError("error.catalina.connector.address.invalid"));
            }
        } else {
            address = null;
        }

        // ports
        numberCheck(oErrors, "portNumber", portText, true, 1, 65535);
        numberCheck(oErrors, "redirectPortText", redirectPortText, true, -1, 65535);

        // SpareThreads Check removed as no more WRITE in the JSP
        /*
        numberCheck(oErrors, "maxThreadsText", maxThreadsText, true, 1, 65535);
        numberCheck(oErrors, "minSpareThreadsText", minSpareThreadsText, true, 1, 65535);
        try {
            // if min is a valid integer, then check that max >= min
            int min = Integer.parseInt(minSpareThreadsText);
            numberCheck(oErrors, "maxSpareThreadsText", maxSpareThreadsText, true, min, 65535);
        }
        catch (Exception e) {
            // check for the complete range
            numberCheck(oErrors, "maxSpareThreadsText", maxSpareThreadsText, true, 1, 65535);
        }*/

        // proxy
        if ((proxyName != null) && (proxyName.length() > 0)) {
            try {
                InetAddress.getByName(proxyName);
            } catch (Exception e) {
                oErrors.add("proxyName"
                    , new ActionError("error.catalina.connector.proxyName.invalid"));
            }
        }

        // supported only by Coyote HTTP and HTTPS connectors
        if (!("AJP".equalsIgnoreCase(connectorType))) {
            numberCheck(oErrors, "proxyPortText", proxyPortText, true, 0, 65535);
        }

        return oErrors;
    }

    /**
     * Helper method to check that it is a required number and
     * is a valid integer within the given range. (min, max).
     *
     * @param  field  The field name in the form for which this error occured.
     * @param  numText  The string representation of the number.
     * @param rangeCheck  Boolean value set to true of reange check should be performed.
     *
     * @param  min  The lower limit of the range
     * @param  max  The upper limit of the range
     * @param  pErrors the ActionErrors
     */
    public void numberCheck(ActionErrors pErrors, String field, String numText, boolean rangeCheck
        , int min, int max) {
        // Check for 'is required'
        if ((numText == null) || (numText.length() < 1)) {
            pErrors.add(field, new ActionError("error.catalina.connector." + field + ".required"));
        } else {

            // check for 'must be a number' in the 'valid range'
            try {
                int num = Integer.parseInt(numText);
                // perform range check only if required
                if (rangeCheck) {
                    if ((num < min) || (num > max)) {
                        pErrors.add(field
                            , new ActionError("error.catalina.connector." + field + ".range"));
                    }
                }
            } catch (NumberFormatException e) {
                pErrors.add(field, new ActionError("error.catalina.connector." + field + ".format"));
            }
        }
    }

// ------------------------------------------------------------- Properties methods

    /**
     * Return the administrative action represented by this form.
     * @return the administrative action
     */
    public String getAction() {
        return this.action;
    }

    /**
     * Set the administrative action represented by this form.
     * @param action the action to set
     */
    public void setAction(String action) {
        this.action = action;
    }

    /**
     * Return the object name of the Connector this bean refers to.
     * @return the object name of the Connector MBean
     */
    public String getObjectName() {
        return this.objectName;
    }

    /**
     * Set the object name of the Connector this bean refers to.
     * @param objectName object name of the Connector MBean
     */
    public void setObjectName(String objectName) {
        this.objectName = objectName;
    }

    /**
     * Return the object name of the service this connector belongs to.
     * @return the object name of the service this connector belongs to
     */
    public String getServiceName() {
        return this.serviceName;
    }

    /**
     * Set the object name of the Service this connector belongs to.
     * @param serviceName the object name of the service this connector belongs to
     */
    public void setServiceName(String serviceName) {
        this.serviceName = serviceName;
    }

    /**
     * Return the Scheme.
     * @return the scheme
     */
    public String getScheme() {
        return this.scheme;
    }

    /**
     * Set the Scheme.
     * @param scheme the scheme to set
     */
    public void setScheme(String scheme) {
        this.scheme = scheme;
    }

    /**
     * Return the Connector type.
     * @return the Connector type
     */
    public String getConnectorType() {
        return this.connectorType;
    }

    /**
     * Set the Connector type.
     * @param connectorType the Connector type to set
     */
    public void setConnectorType(String connectorType) {
        this.connectorType = connectorType;
    }

    /**
     * Return the acceptCountText.
     * @return the acceptCount
     */
    public String getAcceptCountText() {
        return this.acceptCountText;
    }

    /**
     * Set the acceptCountText.
     * @param acceptCountText the acceptCount text
     */
    public void setAcceptCountText(String acceptCountText) {
        this.acceptCountText = acceptCountText;
    }

    /**
     * Return the connTimeOutText.
     * @return the connTimeOut
     */
    public String getConnTimeOutText() {
        return this.connTimeOutText;
    }

    /**
     * Set the connTimeOutText.
     * @param connTimeOutText the connTimeOut text
     */
    public void setConnTimeOutText(String connTimeOutText) {
        this.connTimeOutText = connTimeOutText;
    }

    /**
     * Return the bufferSizeText.
     * @return the bufferSize
     */
    public String getBufferSizeText() {
        return this.bufferSizeText;
    }

    /**
     * Set the bufferSizeText.
     * @param bufferSizeText the bufferSize to set
     */
    public void setBufferSizeText(String bufferSizeText) {
        this.bufferSizeText = bufferSizeText;
    }

    /**
     * Return the address.
     * @return the address
     */
    public String getAddress() {
        return this.address;
    }

    /**
     * Set the address.
     * @param address the address to set
     */
    public void setAddress(String address) {
        this.address = address;
    }

    /**
     * Return the proxy Name.
     * @return the proxy name
     */
    public String getProxyName() {
        return this.proxyName;
    }

    /**
     * Set the proxy Name.
     * @param proxyName the proxy name to set
     */
    public void setProxyName(String proxyName) {
        this.proxyName = proxyName;
    }

    /**
     * Return the proxy Port NumberText.
     * @return the proxy port number
     */
    public String getProxyPortText() {
        return this.proxyPortText;
    }

    /**
     * Set the proxy Port NumberText.
     * @param proxyPortText the proxy port number to set
     */
    public void setProxyPortText(String proxyPortText) {
        this.proxyPortText = proxyPortText;
    }

    /**
     * Return the true/false value of client authentication.
     * @return the value of client authentication
     */
    public boolean isClientAuthentication() {
        return this.clientAuthentication;
    }

    /**
     * Set whether client authentication is supported or not.
     * @param clientAuthentication the client authentication to set or not
     */
    public void setClientAuthentication(boolean clientAuthentication) {
        this.clientAuthentication = clientAuthentication;
    }

    /**
     * @return the keyStore file name
     */
    public String getKeyStoreFileName() {
        return this.keyStoreFileName;
    }

    /**
     * @param keyStoreFileName the keyStore file name to set
     */
    public void setKeyStoreFileName(String keyStoreFileName) {
        this.keyStoreFileName = keyStoreFileName;
    }

    /**
     * @return the keyStore password
     */
    public String getKeyStorePassword() {
        return this.keyStorePassword;
    }

    /**
     * @param keyStorePassword the keyStore password to set
     */
    public void setKeyStorePassword(String keyStorePassword) {
        this.keyStorePassword = keyStorePassword;
    }

    /**
     * Return the debugVals.
     * @return the debug level values
     */
    public List getDebugLvlVals() {
        return this.debugLvlVals;
    }

    /**
     * Set the debugVals.
     * @param debugLvlVals the debug level values
     */
    public void setDebugLvlVals(List debugLvlVals) {
        this.debugLvlVals = debugLvlVals;
    }

    /**
     * Return the Debug Level Text.
     * @return the debug level text
     */
    public String getDebugLvl() {
        return this.debugLvl;
    }

    /**
     * Set the Debug Level Text.
     * @param debugLvl the debug level text to set
     */
    public void setDebugLvl(String debugLvl) {
        this.debugLvl = debugLvl;
    }

    /**
     * Return the Enable lookup Text.
     * @return true if loookups enabled
     */
    public boolean isEnableLookups() {
        return this.enableLookups;
    }

    /**
     * Set the Enable Lookup Text.
     * @param enableLookups Enable Lookup Text
     */
    public void setEnableLookups(boolean enableLookups) {
        this.enableLookups = enableLookups;
    }

    /**
     * Return the booleanVals.
     */
    public List getBooleanVals() {
        return this.booleanVals;
    }

    /**
     * Set the debugVals.
     */
    public void setBooleanVals(List booleanVals) {
        this.booleanVals = booleanVals;
    }

    /**
     * Return the min SpareThreads Text.
     * @return minSpareThreads value
     */
    public String getMinSpareThreadsText() {
        return this.minSpareThreadsText;
    }

    /**
     * Set the minSpareThreads Text.
     * @param minSpareThreadsText minSpareThreads value to set
     */
    public void setMinSpareThreadsText(String minSpareThreadsText) {
        this.minSpareThreadsText = minSpareThreadsText;
    }

    /**
     * Return the max SpareThreads Text.
     * @return maxSpareThreads value
     */
    public String getMaxSpareThreadsText() {
        return this.maxSpareThreadsText;
    }

    /**
     * Set the Max SpareThreads Text.
     * @param maxSpareThreadsText maxSpareThreads value to set
     */
    public void setMaxSpareThreadsText(String maxSpareThreadsText) {
        this.maxSpareThreadsText = maxSpareThreadsText;
    }

    /**
     * Return the max SpareThreads Text.
     * @return maxThreads value
     */
    public String getMaxThreadsText() {
        return this.maxThreadsText;
    }

    /**
     * Set the Max SpareThreads Text.
     * @param maxThreadsText maxSpareThreads value to set
     */
    public void setMaxThreadsText(String maxThreadsText) {
        this.maxThreadsText = maxThreadsText;
    }

    /**
     * Return the port text.
     * @return the port number
     */
    public String getPortText() {
        return this.portText;
    }

    /**
     * Set the port Text.
     * @param portText port to set
     */
    public void setPortText(String portText) {
        this.portText = portText;
    }

    /**
     * Return the port.
     * @return the redirect port number
     */
    public String getRedirectPortText() {
        return this.redirectPortText;
    }

    /**
     * Set the Redirect Port Text.
     * @param redirectPortText the redirect port to set
     */
    public void setRedirectPortText(String redirectPortText) {
        this.redirectPortText = redirectPortText;
    }

    /**
     * @return the connector name
     */
    public String getConnectorName() {
        return this.connectorName;
    }

    /**
     * @param connectorName connector name to set
     */
    public void setConnectorName(String connectorName) {
        this.connectorName = connectorName;
    }

    /**
     * Return the connectorTypeVals.
     * @return the connector types
     */
    public List getConnectorTypeVals() {
        return this.connectorTypeVals;
    }

    /**
     * Set the connectorTypeVals.
     * @param connectorTypeVals the connector types
     */
    public void setConnectorTypeVals(List connectorTypeVals) {
        this.connectorTypeVals = connectorTypeVals;
    }
    /**
     * @return the labels
     */
    public String getLabel() {
        StringBuffer sb = new StringBuffer(getPortText());
        if (getAddress() != null) {
            sb.append(" (");
            sb.append(getAddress());
            sb.append(")");
        }
        return sb.toString();
    }

    /**
     *
     * @return true if save action
     */
    public boolean isSave() {
        return save;
    }

    /**
     *
     * @param save set the save action
     */
    public void setSave(boolean save) {
        this.save = save;
    }
    /**
     * @return the minProcessorsText.
     */
    public String getMinProcessorsText() {
        return minProcessorsText;
    }
    /**
     * @param minProcessorsText the minProcessorsText to set.
     */
    public void setMinProcessorsText(String minProcessorsText) {
        this.minProcessorsText = minProcessorsText;
    }
    /**
     * @return the maxProcessorsText.
     */
    public String getMaxProcessorsText() {
        return maxProcessorsText;
    }
    /**
     * @param maxProcessorsText the maxProcessorsText to set.
     */
    public void setMaxProcessorsText(String maxProcessorsText) {
        this.maxProcessorsText = maxProcessorsText;
    }
}
